Documentation
¶
Index ¶
- type Client
- type ClientService
- type DetailsItems0
- type GetReportBody
- type GetReportDefault
- type GetReportDefaultBody
- type GetReportOK
- type GetReportOKBody
- type GetReportParams
- func (o *GetReportParams) SetBody(body GetReportBody)
- func (o *GetReportParams) SetContext(ctx context.Context)
- func (o *GetReportParams) SetHTTPClient(client *http.Client)
- func (o *GetReportParams) SetTimeout(timeout time.Duration)
- func (o *GetReportParams) WithBody(body GetReportBody) *GetReportParams
- func (o *GetReportParams) WithContext(ctx context.Context) *GetReportParams
- func (o *GetReportParams) WithHTTPClient(client *http.Client) *GetReportParams
- func (o *GetReportParams) WithTimeout(timeout time.Duration) *GetReportParams
- func (o *GetReportParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
- type GetReportReader
- type LabelsItems0
- type RowsItems0
- type RowsItems0MetricsAnon
- type RowsItems0MetricsAnonStats
- type RowsItems0SparklineItems0
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client for profile API
func (*Client) GetReport ¶
func (a *Client) GetReport(params *GetReportParams) (*GetReportOK, error)
GetReport gets report returns list of metrics group by queryid or other dimentions
func (*Client) SetTransport ¶
func (a *Client) SetTransport(transport runtime.ClientTransport)
SetTransport changes the transport on the client
type ClientService ¶
type ClientService interface {
GetReport(params *GetReportParams) (*GetReportOK, error)
SetTransport(transport runtime.ClientTransport)
}
ClientService is the interface for Client methods
func New ¶
func New(transport runtime.ClientTransport, formats strfmt.Registry) ClientService
New creates a new profile API client.
type DetailsItems0 ¶
type DetailsItems0 struct {
// type url
TypeURL string `json:"type_url,omitempty"`
// value
// Format: byte
Value strfmt.Base64 `json:"value,omitempty"`
}
DetailsItems0 details items0 swagger:model DetailsItems0
func (*DetailsItems0) MarshalBinary ¶
func (o *DetailsItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*DetailsItems0) UnmarshalBinary ¶
func (o *DetailsItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetReportBody ¶
type GetReportBody struct {
// period start from
// Format: date-time
PeriodStartFrom strfmt.DateTime `json:"period_start_from,omitempty"`
// period start to
// Format: date-time
PeriodStartTo strfmt.DateTime `json:"period_start_to,omitempty"`
// group by
GroupBy string `json:"group_by,omitempty"`
// labels
Labels []*LabelsItems0 `json:"labels"`
// columns
Columns []string `json:"columns"`
// order by
OrderBy string `json:"order_by,omitempty"`
// offset
Offset int64 `json:"offset,omitempty"`
// limit
Limit int64 `json:"limit,omitempty"`
// main metric
MainMetric string `json:"main_metric,omitempty"`
// search
Search string `json:"search,omitempty"`
}
GetReportBody ReportRequest defines filtering of metrics report for db server or other dimentions. swagger:model GetReportBody
func (*GetReportBody) MarshalBinary ¶
func (o *GetReportBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetReportBody) UnmarshalBinary ¶
func (o *GetReportBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetReportDefault ¶
type GetReportDefault struct {
Payload *GetReportDefaultBody
// contains filtered or unexported fields
}
GetReportDefault handles this case with default header values.
An unexpected error response.
func NewGetReportDefault ¶
func NewGetReportDefault(code int) *GetReportDefault
NewGetReportDefault creates a GetReportDefault with default headers values
func (*GetReportDefault) Code ¶
func (o *GetReportDefault) Code() int
Code gets the status code for the get report default response
func (*GetReportDefault) Error ¶
func (o *GetReportDefault) Error() string
func (*GetReportDefault) GetPayload ¶
func (o *GetReportDefault) GetPayload() *GetReportDefaultBody
type GetReportDefaultBody ¶
type GetReportDefaultBody struct {
// error
Error string `json:"error,omitempty"`
// code
Code int32 `json:"code,omitempty"`
// message
Message string `json:"message,omitempty"`
// details
Details []*DetailsItems0 `json:"details"`
}
GetReportDefaultBody get report default body swagger:model GetReportDefaultBody
func (*GetReportDefaultBody) MarshalBinary ¶
func (o *GetReportDefaultBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetReportDefaultBody) UnmarshalBinary ¶
func (o *GetReportDefaultBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetReportOK ¶
type GetReportOK struct {
Payload *GetReportOKBody
}
GetReportOK handles this case with default header values.
A successful response.
func NewGetReportOK ¶
func NewGetReportOK() *GetReportOK
NewGetReportOK creates a GetReportOK with default headers values
func (*GetReportOK) Error ¶
func (o *GetReportOK) Error() string
func (*GetReportOK) GetPayload ¶
func (o *GetReportOK) GetPayload() *GetReportOKBody
type GetReportOKBody ¶
type GetReportOKBody struct {
// total rows
TotalRows int64 `json:"total_rows,omitempty"`
// offset
Offset int64 `json:"offset,omitempty"`
// limit
Limit int64 `json:"limit,omitempty"`
// rows
Rows []*RowsItems0 `json:"rows"`
}
GetReportOKBody ReportReply is list of reports per quieryids, hosts etc. swagger:model GetReportOKBody
func (*GetReportOKBody) MarshalBinary ¶
func (o *GetReportOKBody) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*GetReportOKBody) UnmarshalBinary ¶
func (o *GetReportOKBody) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type GetReportParams ¶
type GetReportParams struct {
/*Body*/
Body GetReportBody
Context context.Context
HTTPClient *http.Client
// contains filtered or unexported fields
}
GetReportParams contains all the parameters to send to the API endpoint for the get report operation typically these are written to a http.Request
func NewGetReportParams ¶
func NewGetReportParams() *GetReportParams
NewGetReportParams creates a new GetReportParams object with the default values initialized.
func NewGetReportParamsWithContext ¶
func NewGetReportParamsWithContext(ctx context.Context) *GetReportParams
NewGetReportParamsWithContext creates a new GetReportParams object with the default values initialized, and the ability to set a context for a request
func NewGetReportParamsWithHTTPClient ¶
func NewGetReportParamsWithHTTPClient(client *http.Client) *GetReportParams
NewGetReportParamsWithHTTPClient creates a new GetReportParams object with the default values initialized, and the ability to set a custom HTTPClient for a request
func NewGetReportParamsWithTimeout ¶
func NewGetReportParamsWithTimeout(timeout time.Duration) *GetReportParams
NewGetReportParamsWithTimeout creates a new GetReportParams object with the default values initialized, and the ability to set a timeout on a request
func (*GetReportParams) SetBody ¶
func (o *GetReportParams) SetBody(body GetReportBody)
SetBody adds the body to the get report params
func (*GetReportParams) SetContext ¶
func (o *GetReportParams) SetContext(ctx context.Context)
SetContext adds the context to the get report params
func (*GetReportParams) SetHTTPClient ¶
func (o *GetReportParams) SetHTTPClient(client *http.Client)
SetHTTPClient adds the HTTPClient to the get report params
func (*GetReportParams) SetTimeout ¶
func (o *GetReportParams) SetTimeout(timeout time.Duration)
SetTimeout adds the timeout to the get report params
func (*GetReportParams) WithBody ¶
func (o *GetReportParams) WithBody(body GetReportBody) *GetReportParams
WithBody adds the body to the get report params
func (*GetReportParams) WithContext ¶
func (o *GetReportParams) WithContext(ctx context.Context) *GetReportParams
WithContext adds the context to the get report params
func (*GetReportParams) WithHTTPClient ¶
func (o *GetReportParams) WithHTTPClient(client *http.Client) *GetReportParams
WithHTTPClient adds the HTTPClient to the get report params
func (*GetReportParams) WithTimeout ¶
func (o *GetReportParams) WithTimeout(timeout time.Duration) *GetReportParams
WithTimeout adds the timeout to the get report params
func (*GetReportParams) WriteToRequest ¶
func (o *GetReportParams) WriteToRequest(r runtime.ClientRequest, reg strfmt.Registry) error
WriteToRequest writes these params to a swagger request
type GetReportReader ¶
type GetReportReader struct {
// contains filtered or unexported fields
}
GetReportReader is a Reader for the GetReport structure.
func (*GetReportReader) ReadResponse ¶
func (o *GetReportReader) ReadResponse(response runtime.ClientResponse, consumer runtime.Consumer) (interface{}, error)
ReadResponse reads a server response into the received o.
type LabelsItems0 ¶
type LabelsItems0 struct {
// key
Key string `json:"key,omitempty"`
// value
Value []string `json:"value"`
}
LabelsItems0 ReportMapFieldEntry allows to pass labels/dimentions in form like {"server": ["db1", "db2"...]}. swagger:model LabelsItems0
func (*LabelsItems0) MarshalBinary ¶
func (o *LabelsItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*LabelsItems0) UnmarshalBinary ¶
func (o *LabelsItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RowsItems0 ¶
type RowsItems0 struct {
// rank
Rank int64 `json:"rank,omitempty"`
// dimension
Dimension string `json:"dimension,omitempty"`
// database
Database string `json:"database,omitempty"`
// metrics
Metrics map[string]RowsItems0MetricsAnon `json:"metrics,omitempty"`
// sparkline
Sparkline []*RowsItems0SparklineItems0 `json:"sparkline"`
// fingerprint
Fingerprint string `json:"fingerprint,omitempty"`
// num queries
NumQueries int64 `json:"num_queries,omitempty"`
// qps
QPS float32 `json:"qps,omitempty"`
// load
Load float32 `json:"load,omitempty"`
}
RowsItems0 Row define metrics for selected dimention. swagger:model RowsItems0
func (*RowsItems0) MarshalBinary ¶
func (o *RowsItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RowsItems0) UnmarshalBinary ¶
func (o *RowsItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RowsItems0MetricsAnon ¶
type RowsItems0MetricsAnon struct {
// stats
Stats *RowsItems0MetricsAnonStats `json:"stats,omitempty"`
}
RowsItems0MetricsAnon Metric cell. swagger:model RowsItems0MetricsAnon
func (*RowsItems0MetricsAnon) MarshalBinary ¶
func (o *RowsItems0MetricsAnon) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RowsItems0MetricsAnon) UnmarshalBinary ¶
func (o *RowsItems0MetricsAnon) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RowsItems0MetricsAnonStats ¶
type RowsItems0MetricsAnonStats struct {
// rate
Rate float32 `json:"rate,omitempty"`
// cnt
Cnt float32 `json:"cnt,omitempty"`
// sum
Sum float32 `json:"sum,omitempty"`
// min
Min float32 `json:"min,omitempty"`
// max
Max float32 `json:"max,omitempty"`
// p99
P99 float32 `json:"p99,omitempty"`
// avg
Avg float32 `json:"avg,omitempty"`
// sum per sec
SumPerSec float32 `json:"sum_per_sec,omitempty"`
}
RowsItems0MetricsAnonStats Stat is statistics of specific metric. swagger:model RowsItems0MetricsAnonStats
func (*RowsItems0MetricsAnonStats) MarshalBinary ¶
func (o *RowsItems0MetricsAnonStats) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RowsItems0MetricsAnonStats) UnmarshalBinary ¶
func (o *RowsItems0MetricsAnonStats) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RowsItems0SparklineItems0 ¶
type RowsItems0SparklineItems0 struct {
// The serial number of the chart point from the largest time in the time interval to the lowest time in the time range.
Point int64 `json:"point,omitempty"`
// Duration beetween two points.
TimeFrame int64 `json:"time_frame,omitempty"`
// Time of point in format RFC3339.
Timestamp string `json:"timestamp,omitempty"`
// load is query_time / time_range.
Load float32 `json:"load,omitempty"`
// number of queries in bucket.
NumQueriesPerSec float32 `json:"num_queries_per_sec,omitempty"`
// number of queries with errors.
NumQueriesWithErrorsPerSec float32 `json:"num_queries_with_errors_per_sec,omitempty"`
// number of queries with warnings.
NumQueriesWithWarningsPerSec float32 `json:"num_queries_with_warnings_per_sec,omitempty"`
// The statement execution time in seconds.
MQueryTimeSumPerSec float32 `json:"m_query_time_sum_per_sec,omitempty"`
// The time to acquire locks in seconds.
MLockTimeSumPerSec float32 `json:"m_lock_time_sum_per_sec,omitempty"`
// The number of rows sent to the client.
MRowsSentSumPerSec float32 `json:"m_rows_sent_sum_per_sec,omitempty"`
// Number of rows scanned - SELECT.
MRowsExaminedSumPerSec float32 `json:"m_rows_examined_sum_per_sec,omitempty"`
// Number of rows changed - UPDATE, DELETE, INSERT.
MRowsAffectedSumPerSec float32 `json:"m_rows_affected_sum_per_sec,omitempty"`
// The number of rows read from tables.
MRowsReadSumPerSec float32 `json:"m_rows_read_sum_per_sec,omitempty"`
// The number of merge passes that the sort algorithm has had to do.
MMergePassesSumPerSec float32 `json:"m_merge_passes_sum_per_sec,omitempty"`
// Counts the number of page read operations scheduled.
MInnodbIorOpsSumPerSec float32 `json:"m_innodb_io_r_ops_sum_per_sec,omitempty"`
// Similar to innodb_IO_r_ops, but the unit is bytes.
MInnodbIorBytesSumPerSec float32 `json:"m_innodb_io_r_bytes_sum_per_sec,omitempty"`
// Shows how long (in seconds) it took InnoDB to actually read the data from storage.
MInnodbIorWaitSumPerSec float32 `json:"m_innodb_io_r_wait_sum_per_sec,omitempty"`
// Shows how long (in seconds) the query waited for row locks.
MInnodbRecLockWaitSumPerSec float32 `json:"m_innodb_rec_lock_wait_sum_per_sec,omitempty"`
// Shows how long (in seconds) the query spent either waiting to enter the InnoDB queue or inside that queue waiting for execution.
MInnodbQueueWaitSumPerSec float32 `json:"m_innodb_queue_wait_sum_per_sec,omitempty"`
// Counts approximately the number of unique pages the query accessed.
MInnodbPagesDistinctSumPerSec float32 `json:"m_innodb_pages_distinct_sum_per_sec,omitempty"`
// Shows how long the query is.
MQueryLengthSumPerSec float32 `json:"m_query_length_sum_per_sec,omitempty"`
// The number of bytes sent to all clients.
MBytesSentSumPerSec float32 `json:"m_bytes_sent_sum_per_sec,omitempty"`
// Number of temporary tables created on memory for the query.
MTmpTablesSumPerSec float32 `json:"m_tmp_tables_sum_per_sec,omitempty"`
// Number of temporary tables created on disk for the query.
MTmpDiskTablesSumPerSec float32 `json:"m_tmp_disk_tables_sum_per_sec,omitempty"`
// Total Size in bytes for all temporary tables used in the query.
MTmpTableSizesSumPerSec float32 `json:"m_tmp_table_sizes_sum_per_sec,omitempty"`
// Boolean metrics:
// - *_sum_per_sec - how many times this matric was true.
//
// Query Cache hits.
MQcHitSumPerSec float32 `json:"m_qc_hit_sum_per_sec,omitempty"`
// The query performed a full table scan.
MFullScanSumPerSec float32 `json:"m_full_scan_sum_per_sec,omitempty"`
// The query performed a full join (a join without indexes).
MFullJoinSumPerSec float32 `json:"m_full_join_sum_per_sec,omitempty"`
// The query created an implicit internal temporary table.
MTmpTableSumPerSec float32 `json:"m_tmp_table_sum_per_sec,omitempty"`
// The querys temporary table was stored on disk.
MTmpTableOnDiskSumPerSec float32 `json:"m_tmp_table_on_disk_sum_per_sec,omitempty"`
// The query used a filesort.
MFilesortSumPerSec float32 `json:"m_filesort_sum_per_sec,omitempty"`
// The filesort was performed on disk.
MFilesortOnDiskSumPerSec float32 `json:"m_filesort_on_disk_sum_per_sec,omitempty"`
// The number of joins that used a range search on a reference table.
MSelectFullRangeJoinSumPerSec float32 `json:"m_select_full_range_join_sum_per_sec,omitempty"`
// The number of joins that used ranges on the first table.
MSelectRangeSumPerSec float32 `json:"m_select_range_sum_per_sec,omitempty"`
// The number of joins without keys that check for key usage after each row.
MSelectRangeCheckSumPerSec float32 `json:"m_select_range_check_sum_per_sec,omitempty"`
// The number of sorts that were done using ranges.
MSortRangeSumPerSec float32 `json:"m_sort_range_sum_per_sec,omitempty"`
// The number of sorted rows.
MSortRowsSumPerSec float32 `json:"m_sort_rows_sum_per_sec,omitempty"`
// The number of sorts that were done by scanning the table.
MSortScanSumPerSec float32 `json:"m_sort_scan_sum_per_sec,omitempty"`
// The number of queries without index.
MNoIndexUsedSumPerSec float32 `json:"m_no_index_used_sum_per_sec,omitempty"`
// The number of queries without good index.
MNoGoodIndexUsedSumPerSec float32 `json:"m_no_good_index_used_sum_per_sec,omitempty"`
// MongoDB metrics.
//
// The number of returned documents.
MDocsReturnedSumPerSec float32 `json:"m_docs_returned_sum_per_sec,omitempty"`
// The response length of the query result in bytes.
MResponseLengthSumPerSec float32 `json:"m_response_length_sum_per_sec,omitempty"`
// The number of scanned documents.
MDocsScannedSumPerSec float32 `json:"m_docs_scanned_sum_per_sec,omitempty"`
//
// Total number of shared block cache hits by the statement.
MSharedBlksHitSumPerSec float32 `json:"m_shared_blks_hit_sum_per_sec,omitempty"`
MSharedBlksReadSumPerSec float32 `json:"m_shared_blks_read_sum_per_sec,omitempty"`
MSharedBlksDirtiedSumPerSec float32 `json:"m_shared_blks_dirtied_sum_per_sec,omitempty"`
MSharedBlksWrittenSumPerSec float32 `json:"m_shared_blks_written_sum_per_sec,omitempty"`
// Total number of local block cache hits by the statement.
MLocalBlksHitSumPerSec float32 `json:"m_local_blks_hit_sum_per_sec,omitempty"`
// Total number of local blocks read by the statement.
MLocalBlksReadSumPerSec float32 `json:"m_local_blks_read_sum_per_sec,omitempty"`
// Total number of local blocks dirtied by the statement.
MLocalBlksDirtiedSumPerSec float32 `json:"m_local_blks_dirtied_sum_per_sec,omitempty"`
// Total number of local blocks written by the statement.
MLocalBlksWrittenSumPerSec float32 `json:"m_local_blks_written_sum_per_sec,omitempty"`
// Total number of temp blocks read by the statement.
MTempBlksReadSumPerSec float32 `json:"m_temp_blks_read_sum_per_sec,omitempty"`
// Total number of temp blocks written by the statement.
MTempBlksWrittenSumPerSec float32 `json:"m_temp_blks_written_sum_per_sec,omitempty"`
// Total time the statement spent reading blocks, in milliseconds (if track_io_timing is enabled, otherwise zero).
MBlkReadTimeSumPerSec float32 `json:"m_blk_read_time_sum_per_sec,omitempty"`
// Total time the statement spent writing blocks, in milliseconds (if track_io_timing is enabled, otherwise zero).
MBlkWriteTimeSumPerSec float32 `json:"m_blk_write_time_sum_per_sec,omitempty"`
// Total time user spent in query.
MCPUUserTimeSumPerSec float32 `json:"m_cpu_user_time_sum_per_sec,omitempty"`
// Total time system spent in query.
MCPUSysTimeSumPerSec float32 `json:"m_cpu_sys_time_sum_per_sec,omitempty"`
}
RowsItems0SparklineItems0 Point contains values that represents abscissa (time) and ordinate (volume etc.) // of every point in a coordinate system of Sparklines. swagger:model RowsItems0SparklineItems0
func (*RowsItems0SparklineItems0) MarshalBinary ¶
func (o *RowsItems0SparklineItems0) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RowsItems0SparklineItems0) UnmarshalBinary ¶
func (o *RowsItems0SparklineItems0) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation